"""This module provides a custom log handler to push logs to ElasticSearch"""

from __future__ import absolute_import, division, print_function

import logging
from jobcontrol import callback


class JobControlHandler(logging.Handler):
    """Logging handler which pushes logs to the JobControl REST service,
    persisting them in ElasticSearch"""

    def __init__(self, jobrun_id, jobrun_action_id,
                 input_product=None,
                 level=logging.NOTSET,
                 baseurl=callback.CALLBACK_BASE_URL):

        super(JobControlHandler, self).__init__(level=level)

        self.cbc = callback.CallbackClient(baseurl=baseurl)
        self.jobrun_id = jobrun_id
        self.jobrun_action_id = jobrun_action_id
        self.input_product = input_product

    def emit(self, record):

        if self.input_product is None:
            self.cbc.add_jobrun_action_log(self.jobrun_id, self.jobrun_action_id,
                                           self.format(record))
        else:
            self.cbc.add_jobrun_action_product_log(self.jobrun_id, self.jobrun_action_id,
                                                   self.input_product,
                                                   self.format(record))
